@@ -17,11 +17,19 @@ def register_payment_provider(sender, **kwargs):
 def register_global_settings(sender, **kwargs):
     return OrderedDict([
         ('payment_bambora_payform_api_key', forms.CharField(
-            label=_('Bambora Payform: API key'),
+            label=_('Visma Pay: API key'),
             required=False,
         )),
         ('payment_bambora_payform_private_key', forms.CharField(
-            label=_('Bambora Payform: Private key'),
+            label=_('Visma Pay: Private key'),
+            required=False,
+        )),
+        ('payment_bambora_payform_test_api_key', forms.CharField(
+            label=_('Visma Pay: Test API key'),
+            required=False,
+        )),
+        ('payment_bambora_payform_test_private_key', forms.CharField(
+            label=_('Visma Pay: Test private key'),
             required=False,
         )),
     ])
